@@ -14,6 +14,7 @@
 
 import getpass
 import re
+from typing import Union
 
 import click
 
@@ -91,6 +92,23 @@ def create_releases(ctx: TagContext) -> None:
     releasetool.commands.common.publish_via_kokoro(ctx)
 
 
+def kokoro_job_name(upstream_repo: str, package_name: str) -> Union[str, None]:
+    """Return the Kokoro job name.
+
+    Args:
+        upstream_repo (str): The GitHub repo in the form of `<owner>/<repo>`
+        package_name (str): The name of package to release
+
+    Returns:
+        The name of the Kokoro job to trigger or None if there is no job to trigger
+    """
+    return None
+
+
+def package_name(pull: dict) -> Union[str, None]:
+    return None
+
+
 # Note: unlike other languages, the .NET libraries may need multiple
 # tags for a single release PR, usually for dependent APIs, e.g.
 # Google.Cloud.Spanner.Data depending on Google.Cloud.Spanner.V1.
